pub struct FrameTime {
pub delta: Duration,
pub elapsed: Duration,
pub frame_count: u64,
}Expand description
Frame timing information for the app lifecycle.
This is a simplified time struct used by the winit app loop.
For more advanced time features (time scale, fixed timestep, etc.),
use the Time resource from the main astrelis crate.
Example
use astrelis_winit::app::{App, AppCtx};
use astrelis_winit::{FrameTime, WindowId};
use astrelis_winit::event::EventBatch;
use astrelis_winit::window::WindowBackend;
struct MyApp;
impl App for MyApp {
fn update(&mut self, _ctx: &mut AppCtx, time: &FrameTime) {
let dt = time.delta_seconds();
// Use dt for frame-independent movement
let _ = dt; // silence unused warning
}
fn render(&mut self, _ctx: &mut AppCtx, _window_id: WindowId, _events: &mut EventBatch) {
// rendering
}
}Fields
delta: DurationTime elapsed since the last frame
elapsed: DurationTotal time elapsed since app start
frame_count: u64Total number of frames rendered
Implementations